@@ -12,18 +12,20 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-"""
-WatchData object
-"""
+"""WatchData object."""
 
 from oslo_versionedobjects import base
 from oslo_versionedobjects import fields
 
 from heat.db import api as db_api
+from heat.objects import base as heat_base
 from heat.objects import fields as heat_fields
 
 
-class WatchData(base.VersionedObject, base.VersionedObjectDictCompat):
+class WatchData(
+        heat_base.HeatObject,
+        base.VersionedObjectDictCompat,
+):
 
     fields = {
         'id': fields.IntegerField(),
